@@ -5,7 +5,7 @@ import os
 
 from mopidy import config, ext
 
-__version__ = '0.8.1'
+__version__ = '0.9.1'
 
 logger = logging.getLogger(__name__)
 
@@ -26,34 +26,24 @@ class Extension(ext.Extension):
         schema['timeout'] = config.Integer(optional=True, minimum=1)
         schema['use_album_mbid_uri'] = config.Boolean()
         schema['use_artist_mbid_uri'] = config.Boolean()
-        schema['extract_images'] = config.Boolean()
-        schema['image_dir'] = config.String(optional=True)
-        schema['image_base_uri'] = config.String(optional=True)
-        schema['album_art_files'] = config.List(optional=True)
-
         # no longer used
-        schema['encodings'] = config.Deprecated()
-        schema['foreign_keys'] = config.Deprecated()
-        schema['hash'] = config.Deprecated()
-        schema['default_image_extension'] = config.Deprecated()
-
+        schema['extract_images'] = config.Deprecated()
+        schema['image_dir'] = config.Deprecated()
+        schema['image_base_uri'] = config.Deprecated()
+        schema['album_art_files'] = config.Deprecated()
         return schema
 
     def setup(self, registry):
         from .library import SQLiteLibrary
-        from .http import factory
         registry.add('local:library', SQLiteLibrary)
-        registry.add('http:app', {'name': 'sqlite', 'factory': factory})
 
     @classmethod
-    def get_data_dir(cls, config, *paths):
-        # check if Mopidy-Local is enabled
-        if 'local' not in config or 'data_dir' not in config['local']:
+    def get_or_create_data_dir(cls, config):
+        try:
+            data_dir = config['local']['data_dir']
+        except KeyError:
             from mopidy.exceptions import ExtensionError
             raise ExtensionError('Mopidy-Local not enabled')
-        # TODO: use mopidy.utils.path.get_or_create_dir (undocumented)
-        path = os.path.join(config['local']['data_dir'], b'sqlite', *paths)
-        if not os.path.isdir(path):
-            logger.info('Creating directory %s', path)
-            os.makedirs(path, 0755)
-        return path
+        # FIXME: mopidy.utils.path is undocumented
+        from mopidy.utils.path import get_or_create_dir
+        return get_or_create_dir(os.path.join(data_dir, b'sqlite'))
