@@ -6,19 +6,30 @@ import operator
 import os
 import os.path
 import sqlite3
+import sys
 import uritools
 
 from mopidy import local
-from mopidy.local import translator  # FIXME: undocumented Mopidy API
+from mopidy.exceptions import ExtensionError
+from mopidy.local import translator
 from mopidy.models import Ref, SearchResult
+from mopidy.utils.path import uri_to_path
 
 from . import Extension, schema
 
-DBNAME = 'library.db'
+URI_PREFIX = 'local:'
 
 logger = logging.getLogger(__name__)
 
 
+# missing from mopidy.local.translator
+def local_directory_uri_to_path(uri, media_dir):
+    if not uri.startswith('local:directory:'):
+        raise ValueError('Invalid URI.')
+    file_path = uri_to_path(uri).split(b':', 1)[1]
+    return os.path.join(media_dir, file_path)
+
+
 class SQLiteLibrary(local.Library):
 
     ROOT_PATH_URI = 'local:directory:'
@@ -27,24 +38,23 @@ class SQLiteLibrary(local.Library):
 
     def __init__(self, config):
         self._config = ext_config = config[Extension.ext_name]
-        self._dbpath = os.path.join(Extension.get_data_dir(config), DBNAME)
-        self._media_dir = config['local']['media_dir']
+        self._data_dir = Extension.get_or_create_data_dir(config)
+        try:
+            self._media_dir = config['local']['media_dir']
+        except KeyError:
+            raise ExtensionError('Mopidy-Local not enabled')
         self._directories = []
         for line in ext_config['directories']:
             name, uri = line.rsplit(None, 1)
             ref = Ref.directory(uri=uri, name=name)
             self._directories.append(ref)
-        if ext_config['extract_images']:
-            from .images import ImageDirectory
-            self._images = ImageDirectory(config)
-        else:
-            self._images = None
+        self._dbpath = os.path.join(self._data_dir, b'library.db')
         self._connection = None
 
     def load(self):
         with self._connect() as connection:
             version = schema.load(connection)
-            logger.info('Using SQLite database schema v%s', version)
+            logger.debug('Using SQLite database schema v%s', version)
             return schema.count_tracks(connection)
 
     def lookup(self, uri):
@@ -55,7 +65,7 @@ class SQLiteLibrary(local.Library):
             if uri == self.ROOT_DIRECTORY_URI:
                 return self._directories
             elif uri.startswith(self.ROOT_PATH_URI):
-                return self._browse_directory_path(uri)
+                return self._browse_path(uri)
             elif uri.startswith('local:directory'):
                 return self._browse_directory(uri)
             elif uri.startswith('local:artist'):
@@ -87,12 +97,6 @@ class SQLiteLibrary(local.Library):
     def add(self, track):
         try:
             track = self._validate_track(track)
-            if self._images and track.album:
-                uri = translator.local_track_uri_to_file_uri(
-                    track.uri, self._media_dir
-                )
-                album = track.album.copy(images=self._images.scan(uri))
-                track = track.copy(album=album)
             schema.insert_track(self._connect(), track)
         except Exception as e:
             logger.warn('Skipped %s: %s', track.uri, e)
@@ -108,26 +112,17 @@ class SQLiteLibrary(local.Library):
 
     def close(self):
         schema.cleanup(self._connection)
-        if self._images:
-            self._images.cleanup(schema.images(self._connection))
         self._connection.commit()
         self._connection.close()
         self._connection = None
 
     def clear(self):
-        with self._connect() as connection:
-            try:
-                schema.clear(connection)
-            except sqlite3.Error as e:
-                logger.error('Error clearing SQLite database: %s', e)
-                return False
-        if self._images:
-            try:
-                self._images.clear()
-            except Exception as e:
-                logger.error('Error clearing image directory: %s', e)
-                return False
-        return True
+        try:
+            schema.clear(self._connect())
+            return True
+        except sqlite3.Error as e:
+            logger.error('Error clearing SQLite database: %s', e)
+            return False
 
     def _connect(self):
         if not self._connection:
@@ -201,16 +196,17 @@ class SQLiteLibrary(local.Library):
                 logger.warn('Unexpected SQLite browse result: %r', ref)
         return refs
 
-    def _browse_directory_path(self, uri):
-        root = uritools.urisplit(uri).getpath().partition(':')[2]
+    def _browse_path(self, uri, encoding=sys.getfilesystemencoding()):
+        root = local_directory_uri_to_path(uri, b'')
         refs, tracks = [], []
-        for name in sorted(os.listdir(os.path.join(self._media_dir, root))):
-            path = os.path.join(root, name)
-            if os.path.isdir(os.path.join(self._media_dir, path)):
-                uri = translator.path_to_local_directory_uri(path)
+        for file in sorted(os.listdir(os.path.join(self._media_dir, root))):
+            relpath = os.path.join(root, file)
+            name = file.decode(encoding, 'replace')
+            if os.path.isdir(os.path.join(self._media_dir, relpath)):
+                uri = translator.path_to_local_directory_uri(relpath)
                 refs.append(Ref.directory(uri=uri, name=name))
             else:
-                uri = translator.path_to_local_track_uri(path)
+                uri = translator.path_to_local_track_uri(relpath)
                 tracks.append(Ref.track(uri=uri, name=name))
         with self._connect() as c:
             refs += [track for track in tracks if schema.exists(c, track.uri)]
@@ -229,14 +225,14 @@ class SQLiteLibrary(local.Library):
         artists = map(self._validate_artist, album.artists)
         return album.copy(uri=uri, artists=artists)
 
-    def _validate_track(self, track):
+    def _validate_track(self, track, encoding=sys.getfilesystemencoding()):
         if not track.uri:
             raise ValueError('Empty track URI')
         if track.name:
             name = track.name
         else:
             path = translator.local_track_uri_to_path(track.uri, b'')
-            name = os.path.basename(path).decode('utf-8')
+            name = os.path.basename(path).decode(encoding, errors='replace')
         if track.album and track.album.name:
             album = self._validate_album(track.album)
         else:
@@ -250,7 +246,7 @@ class SQLiteLibrary(local.Library):
         )
 
     def _filters(self, uri):
-        if not uri or uri in (self.ROOT_DIRECTORY_URI, self.ROOT_PATH_URI):
+        if uri in (URI_PREFIX, self.ROOT_DIRECTORY_URI, self.ROOT_PATH_URI):
             return []
         elif uri.startswith(self.ROOT_PATH_URI):
             return [{'uri': uri.replace('directory', 'track', 1) + '/*'}]
@@ -261,7 +257,8 @@ class SQLiteLibrary(local.Library):
         elif uri.startswith('local:album'):
             return [{'album': uri}]
         else:
-            raise ValueError('Invalid search URI: %s', uri)
+            logger.warn('Invalid search URI: %s', uri)
+            return []
 
     def _model_uri(self, type, model):
         if model.musicbrainz_id and self._config['use_%s_mbid_uri' % type]:
