@@ -5,7 +5,7 @@ import tempfile
 import unittest
 
 from mopidy.local import translator
-from mopidy.models import Track
+from mopidy.models import SearchResult, Track
 from mopidy_local_sqlite import library
 
 
@@ -42,7 +42,7 @@ class LocalLibraryProviderTest(unittest.TestCase):
 
     def test_add_noname_utf8(self):
         name = u'Mi\xf0vikudags.mp3'
-        uri = translator.path_to_local_track_uri(name)
+        uri = translator.path_to_local_track_uri(name.encode('utf-8'))
         self.library.begin()
         self.library.add(Track(uri=uri))
         self.library.close()
@@ -54,3 +54,12 @@ class LocalLibraryProviderTest(unittest.TestCase):
         self.library.close()
         self.library.clear()
         self.assertEqual(self.library.load(), 0)
+
+    def test_search_uri(self):
+        empty = SearchResult(uri='local:search?')
+        self.assertEqual(empty, self.library.search(uris=None))
+        self.assertEqual(empty, self.library.search(uris=[]))
+        self.assertEqual(empty, self.library.search(uris=['local:']))
+        self.assertEqual(empty, self.library.search(uris=['local:directory']))
+        self.assertEqual(empty, self.library.search(uris=['local:directory:']))
+        self.assertEqual(empty, self.library.search(uris=['foobar:']))
